@@ -1,11 +1,11 @@
-use swc_common::collections::AHashSet;
+use rustc_hash::FxHashSet;
 use swc_ecma_ast::*;
 use swc_ecma_utils::{find_ids, ident::IdentLike, Id};
 use swc_ecma_visit::{noop_visit_type, Visit, VisitWith};
 
 use crate::option::MangleOptions;
 
-pub(super) fn idents_to_preserve<N>(options: MangleOptions, n: &N) -> AHashSet<Id>
+pub(super) fn idents_to_preserve<N>(options: MangleOptions, n: &N) -> FxHashSet<Id>
 where
     N: VisitWith<Preserver>,
 {
@@ -20,7 +20,7 @@ where
 }
 pub(super) struct Preserver {
     options: MangleOptions,
-    preserved: AHashSet<Id>,
+    preserved: FxHashSet<Id>,
     should_preserve: bool,
     in_top_level: bool,
 }
